@@ -10,11 +10,11 @@ Interchange6::Schema - Database Schema for Interchange 6
 
 =head1 VERSION
 
-0.090
+0.091
 
 =cut
 
-our $VERSION = '0.090';
+our $VERSION = '0.091';
 
 =head1 DESCRIPTION
 
@@ -38,10 +38,10 @@ The minimum Perl version for Interchange6::Schema is 5.14.
 use strict;
 use warnings;
 
-use base 'DBIx::Class::Schema';
+use base 'DBIx::Class::Schema::Config';
 
 __PACKAGE__->load_components( 'Helper::Schema::DateTime',
-    'Helper::Schema::QuoteNames', 'Schema::Config' );
+    'Helper::Schema::QuoteNames' );
 
 __PACKAGE__->load_namespaces(
     default_resultset_class => 'ResultSet',
