@@ -99,6 +99,20 @@ column content => {
     data_type         => "text"
 };
 
+=head2 summary
+
+Summary/teaser for L</content>.
+
+Defaults to empty string.
+
+=cut
+
+column summary => {
+    data_type     => "varchar",
+    size          => 1024,
+    default_value => '',
+};
+
 =head2 author_users_id
 
 Foreign key constraint on L<Interchange6::Schema::Result::User/users_id>
