@@ -21,6 +21,27 @@ use parent 'Interchange6::Schema::ResultSet';
 
 =head1 METHODS
 
+=head2 find
+
+Override L<DBIx::Class::ResultSet/find> for lookup of
+L<Interchange6::Schema::Result::User/username> so that leading/trailing spaces
+are stripped from username and it is also lower-cased.
+
+=cut
+
+sub find {
+    my $self = shift;
+
+    if ( ref( $_[0] ) eq 'HASH' && defined $_[0]->{username} ) {
+
+        # looking for a username
+        $_[0]->{username} = lc( $_[0]->{username} );
+        $_[0]->{username} =~ s/(^\s+|\s+$)//g;
+    }
+
+    $self->next::method(@_);
+}
+
 =head2 find_user_with_reset_token( $token );
 
 Where $token is the combined <Interchange6::Schema::Result::User/reset_token>
